#
# spec file for package messagelib
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf5_version 5.26.0
# Latest stable Applications (e.g. 17.08 in KA, but 17.11.80 in KUA)
%{!?_kapp_version: %define _kapp_version %(echo %{version}| awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           messagelib
Version:        18.12.3
Release:        lp151.2.4.1
Summary:        KDE PIM library for e-mail message parsing and display
License:        GPL-2.0-only AND GPL-3.0-only AND LGPL-2.1-or-later
Group:          System/Libraries
URL:            http://www.kde.org
Source0:        %{name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM
Patch0:         CVE-2019-10732.patch
BuildRequires:  akonadi-contact-devel
BuildRequires:  akonadi-mime-devel
BuildRequires:  akonadi-search-devel
BuildRequires:  akonadi-server-devel
BuildRequires:  extra-cmake-modules
BuildRequires:  grantlee5-devel
BuildRequires:  grantleetheme-devel
BuildRequires:  karchive-devel
BuildRequires:  kcodecs-devel
BuildRequires:  kcompletion-devel
BuildRequires:  kconfig-devel
BuildRequires:  kcontacts-devel
BuildRequires:  kdepim-apps-libs-devel
BuildRequires:  kf5-filesystem
BuildRequires:  ki18n-devel
BuildRequires:  kiconthemes-devel
BuildRequires:  kidentitymanagement-devel
BuildRequires:  kimap-devel
BuildRequires:  kitemviews-devel
BuildRequires:  kldap-devel
BuildRequires:  kmailtransport-devel
BuildRequires:  kmbox-devel
BuildRequires:  kmime-devel
BuildRequires:  kpimtextedit-devel
BuildRequires:  kxmlgui-devel
BuildRequires:  libQt5Sql-private-headers-devel
BuildRequires:  libgpgme-devel
BuildRequires:  libgpgmepp-devel
BuildRequires:  libgravatar-devel
BuildRequires:  libkdepim-devel
BuildRequires:  libkleo-devel
BuildRequires:  libqgpgme-devel
BuildRequires:  pimcommon-devel
BuildRequires:  pkgconfig
BuildRequires:  syntax-highlighting-devel
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.4.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.4.0
BuildRequires:  pkgconfig(Qt5Sql) >= 5.4.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.4.0
BuildRequires:  pkgconfig(Qt5UiTools) >= 5.4.0
BuildRequires:  pkgconfig(Qt5WebEngine) >= 5.4.0
BuildRequires:  pkgconfig(Qt5WebEngineWidgets) >= 5.4.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.4.0
# It can only build on the same platforms as Qt Webengine
ExclusiveArch:  %{ix86} x86_64 %{arm} aarch64 mips mips64
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
%if %{with lang}
Recommends:     %{name}-lang
%endif

%description
This package contains the messagelib library. It is used by KDE PIM to parse and
display emails.

%package devel
Summary:        Library for messages
License:        LGPL-2.1-or-later
Group:          Development/Libraries/KDE
Requires:       %{name} = %{version}
Requires:       akonadi-mime-devel
Requires:       akonadi-server-devel
Requires:       kcontacts-devel
Requires:       kidentitymanagement-devel
Requires:       kmime-devel
Requires:       libkleo-devel
Requires:       messagelib-devel
Requires:       pimcommon-devel
%if 0%{?suse_version} > 1325
Requires:       libboost_headers-devel
%else
Requires:       boost-devel
%endif

%description devel
This package contains source headers for messagelib.

%if %{with lang}
%lang_package
%endif

%prep
%setup -q
%autopatch -p1

%build
%cmake_kf5 -d build -- -DMESSAGEVIEWER_USE_QTWEBENGINE=TRUE -DQTWEBENGINE_SUPPORT_OPTION=TRUE
%make_jobs

%install
%kf5_makeinstall -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
%endif

%post   -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files devel
%license COPYING*
%{_kf5_cmakedir}/KF5MessageComposer/
%{_kf5_cmakedir}/KF5MessageCore/
%{_kf5_cmakedir}/KF5MessageList/
%{_kf5_cmakedir}/KF5MessageViewer/
%{_kf5_cmakedir}/KF5MimeTreeParser/
%{_kf5_cmakedir}/KF5TemplateParser/
%{_kf5_cmakedir}/KF5WebEngineViewer/
%{_kf5_includedir}/
%{_kf5_libdir}/libKF5MessageComposer.so
%{_kf5_libdir}/libKF5MessageCore.so
%{_kf5_libdir}/libKF5MessageList.so
%{_kf5_libdir}/libKF5MessageViewer.so
%{_kf5_libdir}/libKF5MimeTreeParser.so
%{_kf5_libdir}/libKF5TemplateParser.so
%{_kf5_libdir}/libKF5WebEngineViewer.so
%{_kf5_mkspecsdir}/qt_*.pri

%files
%license COPYING*
%config %{_kf5_configdir}/messagelib.categories
%config %{_kf5_configdir}/messagelib.renamecategories
%config %{_kf5_configdir}/messageviewer_header_themes.knsrc
%dir %{_kf5_sharedir}/org.kde.syntax-highlighting
%dir %{_kf5_sharedir}/org.kde.syntax-highlighting/syntax
%{_kf5_sharedir}/org.kde.syntax-highlighting/syntax/kmail-template.xml
%{_kf5_configkcfgdir}/*.kcfg
%{_kf5_libdir}/libKF5MessageComposer.so.*
%{_kf5_libdir}/libKF5MessageCore.so.*
%{_kf5_libdir}/libKF5MessageList.so.*
%{_kf5_libdir}/libKF5MessageViewer.so.*
%{_kf5_libdir}/libKF5MimeTreeParser.so.*
%{_kf5_libdir}/libKF5TemplateParser.so.*
%{_kf5_libdir}/libKF5WebEngineViewer.so.*
%{_kf5_notifydir}/messageviewer.notifyrc
%{_kf5_plugindir}/messageviewer/
%{_kf5_sharedir}/kconf_update/
%{_kf5_sharedir}/libmessageviewer/
%{_kf5_sharedir}/messagelist/
%{_kf5_sharedir}/messageviewer/

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Fri Nov 29 2019 wbauer@tmo.at
- Add CVE-2019-10732.patch to prevent accidental disclosure of
  encrypted content when replying
  (boo#1131885, kde#404698, CVE-2019-10732)
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * Fix runtime warning when calling deleteLater on a null object.
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * Fix Bug 403460 - Expand BCC list of emails button is oriented in non-intuitive direction (kde#403460)
  * Disable code for the moment
  * Don't show "Attachment:" when there is a mail embedded
  * Avoid to wrap word
  * It was fixed in kmime
  * Fix show attachment as reported by David.
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * api.longurl.org doesn't work now. Use lengthenurl.info
  * inform when we can't expand url
  * Don't generate string when it's not necessary
  * Fix Bug 402378 - mailto staement , uncomplete url past to kmail composer (kde#402378)
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Make sure to not update when not necessary
  * Add autotests for excluding some "head"
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * templateparserextracthtmlinfo.cpp - deleteLater in dtor (kde#401337)
  * Fix return value
  * Remove unused variable
  * Already initialized in header
  * Fix mem leak
  * Add parent to menu (Fix potential mem leak)
  * Fix export class
  * Clean icon theme when we delete theme class
  * Exclude Refresh from MetaData (Not necessary)
  * Fix mem leak found by asan
  * Fix API (need for fixing mem leak found by asan)
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * Fix Bug 377708 - KMail doesn't remember to render in HTML (kde#377708)
  * Fix Bug 396398 - KMail 5.8.2 displays HTML formatting on top of message (kde#396398)
  * Check QtWebEngine version instead of Qt's (kde#397349)
- Dropped patches, now upstream:
  * 0001-Check-QtWebEngine-version-instead-of-Qt-s.patch
* Wed Oct 24 2018 wbauer@tmo.at
- Add 0001-Check-QtWebEngine-version-instead-of-Qt-s.patch to fix
  behavior of the PgUp/PgDown and Space keys in the messageviewer
  when QtWebEngine 5.10+ is used in combination with Qt 5.9 as in
  Leap 15 (boo#1105461, kde#397349)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Relicense my code from GPLv2 to GPLv2+
  * Define color for openpgp signature
  * Store transport name and identity name
  * Don't save X-KMail-Fcc it's redundant
  * We need theses header when we resend file
* Sat Sep  8 2018 fabian@ritter-vogt.de
- Remove unnecessary kdewebkit-devel BuildReq
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Make sure that we can create a followupreminder
  * Show info debug
  * Fix Bug 397011 - Add Followup Reminder doesn't create reminder correctly (kde#397011)
  * Run UrlHandlerManagerTest inside the Akonad isolated environment
  * Fix block tracking url
  * Allow to close dialog
  * Make CI happy
  * Warning--
  * Avoid warning about "device not open"
  * Fix autotest
  * Fix autotest
  * Fix false positive
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * It seems that we need to register it
  * Make sure that we load "disable emoticon" for header too
  * Save "disable emoticon" when we change this value
  * Don't show "Show detail" when we print mail
  * We need to add isPrinting variable (otherwise it will not work)
  * Fix link color/style text when we print mail
  * Fix indent
  * Fix rendering text. We can have Utf8 text
  * Fix printing support in signedmessage.
  * avoid crash by initializing pointer
  * Significant performance increase for specific use conditions
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Avoid to display all message in preview
  * Fix dnd attachment with qt5.11
- Dropped patches, now upstream:
  * 0001-Fix-dnd-attachment-with-qt5.11.patch
* Thu Jun 14 2018 lbeltrame@kde.org
- Add upstream patch 0001-Fix-dnd-attachment-with-qt5.11.patch:
  * Fixes drag-and-drop of attachments between message windows
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Ensure we always reset the external reference override (kde#394554)
  * QtWebEngine 5.11 can intercept more messages include local and data ones
- Dropped patches, now upstream:
  * always-reset-external-reference-override.patch
* Sat May 26 2018 lbeltrame@kde.org
- Add upstream patch always-reset-external-reference-override.patch:
  * Fix regression causing KMail to load external references
    in HTML messages without asking (kde#394554)
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Now when we use ESC we force focus on viewer
  * Use >=
  * Fix Bug 393688 - DND Attachments from one existing message to new message (kde#393688)
  * Distinguish between settings and explicit override for external content
  * Load external references in encrypted emails only on explicit request
  * Remove unused variable
  * Clean up css
  * Fix expand/collapse addresslist
  * Fix size
  * Cache value
  * Use directly css. Remove script for show full address. I know that some autotests are broken
  * Clean up
  * Cache number of identity
  * Cache string
  * Add comment
  * Minor optimization
  * Add comment
  * initialize value
  * Warning--
  * Minor optimization
  * Don't use injection code for attachment
  * Return attachmentHtml directly
  * Remove show/hide method
  * Remove hide/show attachment as discussed this WE.
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * kde389592.patch
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Reactivate code now
  * Reactivate scroll to
  * Remove some yellow style
  * Activate it
  * Fix add/remove yellow mark
  * Workaround bug found by David.
  * Patch from aleksejshilin
* Fri Feb 16 2018 wbauer@tmo.at
- Add kde389592.patch to fix "Disable Emoticons" option not being
  remembered (boo#1078174, kde#389592)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Add normal text too. So we can switch from html to normal text too
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Repair Page Down with Qt 5.9, there documentElement.scrollTop doesn't work.
  * Fix Bug 388440 - scrolling in KMail: "page down" only works once (kde#388440)
  * Add the values of the Inotify find call to the appropriate lists
  * Not necessary to use private class here
  * Hide widget when we change message
- Dropped patches, now upstream:
  * 0001-Fix-Bug-388440-scrolling-in-KMail-page-down-only-wor.patch
* Tue Jan  2 2018 fabian@ritter-vogt.de
- Add patch to fix scrolling with Qt >= 5.10 (boo#1074271):
  * 0001-Fix-Bug-388440-scrolling-in-KMail-page-down-only-wor.patch
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * Fix crash when we delete attachment
  * fix x-kmail links with arguments
* Tue Nov 21 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * fix-richtext-saving.patch
* Tue Nov 21 2017 lbeltrame@kde.org
- Add fix-richtext-saving.patch: fix the state of rich text saving
  in KMail's composer (kde#386660)
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Fix Bug 386368 - Links in HTML emails broken by escaped ampersands (kde#386368)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Allow to show html source even if we have build as release
  * Add parent to qdialogbuttonbox
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Hide "to:" if "to" is empty
  * Fix potential crash
  * Fix url
  * Fix setting custom header color in message list theme editor
  * Fix 'lambda-expression in unevaluated context' error
  * Allow to react when we click on url and other
  * Improve default color
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sun Jul 16 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * Don't create link when path is empty
  * Use floating point calculations for column sizes to avoid accumulating rounding errors
  * messagelist: fix horizontal scrollbar when applying column sizes
  * Fix Bug 380297 - Recipients counter miscounts number of message recipients (kde#380297)
  * Remove include
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Make sure to sign/encrypt message when we send later
  * Change encryption too
  * Fix potential crash as david reported
  * Workaround assert in QtWebEngine 5.9 (ASSERT: "m_updateHttpCache")
  * Fix runtime warning about application/x-pkcs7-signature.
  * Use QTemporaryDir as discussed with David
  * Fix Bug 378526 - KMail 5.4.3: Attachment displayed with wrong filename (kde#378526)
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * Use base64 encoding for all non-text attachments (kde#95733)
  * crypto unittests can't be run in parallel since they start/stop gpg-agent
  * Don't break i18n
  * Fix Bug 379066 - Bug in Grantlee template when viewing SMIME Msg: plain HTML code is shown (kde#379066)
  * Handle help:/ URLs through QDesktopServices
  * [autotests] repair mailwebenginescripttest after my changes in 37b99257
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Port isScrolledToBottom from jQuery to standard DOM, so it works even when jQuery isn't loaded
  * Rework timing of script injection for showing attachments in message viewer.
  * Use QFileInfo::exists(...) static method here
  * [autotests] more work towards stable autotests
  * [autotests] Let's see if this fixes the flakiness of the test
  * [autotests] Enable test mode in QStandardPaths to avoid interference from user settings.
  * Avoid timeout
  * Don't continue when we have error during compression.
  * Use QByteArrayLiteral here
  * [autotest] avoid timeout due to waiting for klauncher to exit
  * Use the same name as filename and name. It's more logical as discussed with David
  * Const'ify here
  * Use QByteArrayLiteral here
  * Use nullptr
  * Fix typo as reported by David
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * Minor optimization
  * Minor optimization
  * Fix html here too
  * Fix i18n(...) it's a "block" variable here.
  * Reduce number of toUpper calling
  * Fix gpgsm processes being leaked due to QGpgME::KeyListJob not being deleted
  * Add metainfo.yaml
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix Bug 377247 - kMail 2 does not properly escape header (kde#377247)
  * Use correct variable for date direction
  * Finish removing the user agent from sent emails.
  * Rename method as requested by David
  * Keep "disable emoticon" state even if we switch message
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Tue Aug 23 2016 fabian@ritter-vogt.de
- Build only on architectures supported by libqt5-qtwebengine
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul 21 2016 wbauer@tmo.at
- Cleanup build requirements
- Add necessary dependencies to the devel package
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
